@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,7 +24,7 @@
 #include <QCryptographicHash>
 #include <QPixmap>
 #include <QStandardPaths>
-#include <qtest.h>
+#include <QTest>
 
 using namespace Gravatar;
 
